@@ -51,6 +51,9 @@ from openapi_client.model.catalog_category_update_job_create_query_as_sub_resour
 from openapi_client.model.catalog_category_update_query import CatalogCategoryUpdateQuery
 from openapi_client.model.catalog_category_update_query_as_sub_resource import CatalogCategoryUpdateQueryAsSubResource
 from openapi_client.model.catalog_category_update_query_as_sub_resource_attributes import CatalogCategoryUpdateQueryAsSubResourceAttributes
+from openapi_client.model.catalog_category_update_query_as_sub_resource_relationships import CatalogCategoryUpdateQueryAsSubResourceRelationships
+from openapi_client.model.catalog_category_update_query_as_sub_resource_relationships_items import CatalogCategoryUpdateQueryAsSubResourceRelationshipsItems
+from openapi_client.model.catalog_category_update_query_as_sub_resource_relationships_items_data_inner import CatalogCategoryUpdateQueryAsSubResourceRelationshipsItemsDataInner
 from openapi_client.model.catalog_item_category_op import CatalogItemCategoryOp
 from openapi_client.model.catalog_item_create_job_create_query import CatalogItemCreateJobCreateQuery
 from openapi_client.model.catalog_item_create_job_create_query_as_sub_resource import CatalogItemCreateJobCreateQueryAsSubResource
@@ -78,9 +81,6 @@ from openapi_client.model.catalog_variant_create_job_create_query_as_sub_resourc
 from openapi_client.model.catalog_variant_create_query import CatalogVariantCreateQuery
 from openapi_client.model.catalog_variant_create_query_as_sub_resource import CatalogVariantCreateQueryAsSubResource
 from openapi_client.model.catalog_variant_create_query_as_sub_resource_attributes import CatalogVariantCreateQueryAsSubResourceAttributes
-from openapi_client.model.catalog_variant_create_query_as_sub_resource_relationships import CatalogVariantCreateQueryAsSubResourceRelationships
-from openapi_client.model.catalog_variant_create_query_as_sub_resource_relationships_items import CatalogVariantCreateQueryAsSubResourceRelationshipsItems
-from openapi_client.model.catalog_variant_create_query_as_sub_resource_relationships_items_data_inner import CatalogVariantCreateQueryAsSubResourceRelationshipsItemsDataInner
 from openapi_client.model.catalog_variant_delete_job_create_query import CatalogVariantDeleteJobCreateQuery
 from openapi_client.model.catalog_variant_delete_job_create_query_as_sub_resource import CatalogVariantDeleteJobCreateQueryAsSubResource
 from openapi_client.model.catalog_variant_delete_job_create_query_as_sub_resource_attributes import CatalogVariantDeleteJobCreateQueryAsSubResourceAttributes
@@ -91,10 +91,15 @@ from openapi_client.model.catalog_variant_update_job_create_query_as_sub_resourc
 from openapi_client.model.catalog_variant_update_query import CatalogVariantUpdateQuery
 from openapi_client.model.catalog_variant_update_query_as_sub_resource import CatalogVariantUpdateQueryAsSubResource
 from openapi_client.model.catalog_variant_update_query_as_sub_resource_attributes import CatalogVariantUpdateQueryAsSubResourceAttributes
+from openapi_client.model.collection_links import CollectionLinks
 from openapi_client.model.content_sub_object import ContentSubObject
 from openapi_client.model.data_privacy_create_deletion_job_query import DataPrivacyCreateDeletionJobQuery
 from openapi_client.model.data_privacy_create_deletion_job_query_as_sub_resource import DataPrivacyCreateDeletionJobQueryAsSubResource
 from openapi_client.model.data_privacy_create_deletion_job_query_as_sub_resource_attributes import DataPrivacyCreateDeletionJobQueryAsSubResourceAttributes
+from openapi_client.model.email_channel import EmailChannel
+from openapi_client.model.email_marketing import EmailMarketing
+from openapi_client.model.email_marketing_list_suppression import EmailMarketingListSuppression
+from openapi_client.model.email_marketing_suppression import EmailMarketingSuppression
 from openapi_client.model.email_message_content import EmailMessageContent
 from openapi_client.model.email_tracking_options import EmailTrackingOptions
 from openapi_client.model.error_source import ErrorSource
@@ -104,15 +109,15 @@ from openapi_client.model.event_create_query_as_sub_resource_attributes import E
 from openapi_client.model.flow_update_query import FlowUpdateQuery
 from openapi_client.model.flow_update_query_as_sub_resource import FlowUpdateQueryAsSubResource
 from openapi_client.model.flow_update_query_as_sub_resource_attributes import FlowUpdateQueryAsSubResourceAttributes
-from openapi_client.model.get_campaigns4_xx_response import GetCampaigns4XXResponse
-from openapi_client.model.get_campaigns4_xx_response_errors_inner import GetCampaigns4XXResponseErrorsInner
-from openapi_client.model.get_campaigns4_xx_response_errors_inner_source import GetCampaigns4XXResponseErrorsInnerSource
+from openapi_client.model.get_create_variants_jobs5_xx_response import GetCreateVariantsJobs5XXResponse
+from openapi_client.model.get_create_variants_jobs5_xx_response_errors_inner import GetCreateVariantsJobs5XXResponseErrorsInner
+from openapi_client.model.get_create_variants_jobs5_xx_response_errors_inner_source import GetCreateVariantsJobs5XXResponseErrorsInnerSource
 from openapi_client.model.included_categories import IncludedCategories
 from openapi_client.model.included_categories_attributes import IncludedCategoriesAttributes
 from openapi_client.model.included_flow_action import IncludedFlowAction
+from openapi_client.model.included_flow_action_attributes import IncludedFlowActionAttributes
+from openapi_client.model.included_flow_action_attributes_tracking_options import IncludedFlowActionAttributesTrackingOptions
 from openapi_client.model.included_flow_actions import IncludedFlowActions
-from openapi_client.model.included_flow_actions_attributes import IncludedFlowActionsAttributes
-from openapi_client.model.included_flow_actions_attributes_tracking_options import IncludedFlowActionsAttributesTrackingOptions
 from openapi_client.model.included_flow_messages import IncludedFlowMessages
 from openapi_client.model.included_flow_messages_attributes import IncludedFlowMessagesAttributes
 from openapi_client.model.included_flow_messages_attributes_content import IncludedFlowMessagesAttributesContent
@@ -129,22 +134,23 @@ from openapi_client.model.included_profiles_attributes import IncludedProfilesAt
 from openapi_client.model.included_segments import IncludedSegments
 from openapi_client.model.included_segments_attributes import IncludedSegmentsAttributes
 from openapi_client.model.included_tags import IncludedTags
+from openapi_client.model.included_tags_attributes import IncludedTagsAttributes
 from openapi_client.model.included_variants import IncludedVariants
 from openapi_client.model.included_variants_attributes import IncludedVariantsAttributes
-from openapi_client.model.included_variants_links import IncludedVariantsLinks
 from openapi_client.model.list_create_query import ListCreateQuery
 from openapi_client.model.list_create_query_as_sub_resource import ListCreateQueryAsSubResource
-from openapi_client.model.list_create_query_as_sub_resource_attributes import ListCreateQueryAsSubResourceAttributes
 from openapi_client.model.list_members_add_query import ListMembersAddQuery
 from openapi_client.model.list_members_add_query_data_inner import ListMembersAddQueryDataInner
 from openapi_client.model.list_members_delete_query import ListMembersDeleteQuery
 from openapi_client.model.list_partial_update_query import ListPartialUpdateQuery
 from openapi_client.model.list_partial_update_query_as_sub_resource import ListPartialUpdateQueryAsSubResource
+from openapi_client.model.list_partial_update_query_as_sub_resource_attributes import ListPartialUpdateQueryAsSubResourceAttributes
 from openapi_client.model.metric_aggregate_query import MetricAggregateQuery
 from openapi_client.model.metric_aggregate_query_as_sub_resource import MetricAggregateQueryAsSubResource
 from openapi_client.model.metric_aggregate_query_as_sub_resource_attributes import MetricAggregateQueryAsSubResourceAttributes
 from openapi_client.model.metric_aggregate_row_dto import MetricAggregateRowDTO
 from openapi_client.model.metric_create_query import MetricCreateQuery
+from openapi_client.model.object_links import ObjectLinks
 from openapi_client.model.onsite_profile_create_query import OnsiteProfileCreateQuery
 from openapi_client.model.onsite_profile_create_query_as_sub_resource import OnsiteProfileCreateQueryAsSubResource
 from openapi_client.model.onsite_profile_meta import OnsiteProfileMeta
@@ -160,6 +166,9 @@ from openapi_client.model.profile_location_latitude import ProfileLocationLatitu
 from openapi_client.model.profile_location_longitude import ProfileLocationLongitude
 from openapi_client.model.profile_partial_update_query import ProfilePartialUpdateQuery
 from openapi_client.model.profile_partial_update_query_as_sub_resource import ProfilePartialUpdateQueryAsSubResource
+from openapi_client.model.profile_partial_update_query_as_sub_resource_attributes import ProfilePartialUpdateQueryAsSubResourceAttributes
+from openapi_client.model.sms_channel import SMSChannel
+from openapi_client.model.sms_marketing import SMSMarketing
 from openapi_client.model.sms_message_content import SMSMessageContent
 from openapi_client.model.sms_render_options import SMSRenderOptions
 from openapi_client.model.sms_tracking_options import SMSTrackingOptions
@@ -177,6 +186,7 @@ from openapi_client.model.subscription_channels import SubscriptionChannels
 from openapi_client.model.subscription_create_job_create_query import SubscriptionCreateJobCreateQuery
 from openapi_client.model.subscription_create_job_create_query_as_sub_resource import SubscriptionCreateJobCreateQueryAsSubResource
 from openapi_client.model.subscription_create_job_create_query_as_sub_resource_attributes import SubscriptionCreateJobCreateQueryAsSubResourceAttributes
+from openapi_client.model.subscriptions import Subscriptions
 from openapi_client.model.suppression import Suppression
 from openapi_client.model.suppression_create_job_create_query import SuppressionCreateJobCreateQuery
 from openapi_client.model.suppression_create_job_create_query_as_sub_resource import SuppressionCreateJobCreateQueryAsSubResource
@@ -194,7 +204,6 @@ from openapi_client.model.tag_segment_op import TagSegmentOp
 from openapi_client.model.tag_segment_op_data_inner import TagSegmentOpDataInner
 from openapi_client.model.tag_update_query import TagUpdateQuery
 from openapi_client.model.tag_update_query_as_sub_resource import TagUpdateQueryAsSubResource
-from openapi_client.model.tag_update_query_as_sub_resource_attributes import TagUpdateQueryAsSubResourceAttributes
 from openapi_client.model.template_clone_query import TemplateCloneQuery
 from openapi_client.model.template_clone_query_as_sub_resource import TemplateCloneQueryAsSubResource
 from openapi_client.model.template_clone_query_as_sub_resource_attributes import TemplateCloneQueryAsSubResourceAttributes
